#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// This indcator shows how to access Orderflow data
    /// </summary>
    [Description("This indicator shows how to access Orderflow data")]
    public class GomTestBuySells : Indicator
    {
 
		GomOrderFlowProValues  gof;

		
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Green), PlotStyle.Line, "MaxBuys"));
            Add(new Plot(Color.FromKnownColor(KnownColor.Red), PlotStyle.Line, "MaxSells"));
            Overlay				= false;
			BarsRequired=0;
        }

		protected override void OnStartUp()
		{
			gof=GomOrderFlowProValues(true, Gom.DeltaLib.DeltaCalcType.UpDownTick,Gom.OrderFlow.ImbalanceComparisonType.Ratio,
				Gom.OrderFlow.ImbalanceDirectionType.Diagonal, 3, Gom.OrderFlow.ImbalanceComparisonType.Ratio,Gom.OrderFlow.ImbalanceDirectionType.None, 
				3,false, -1,0, -1, 3, 1, 0, false,Gom.OrderFlow.ReversalPocPositionType.Anywhere, 0, 3, 1);			

		}

        protected override void OnBarUpdate()
        {	
			//update gof indicator
			gof.Update();
			
			//gof.BarData contains the buys/sells values from all the bars. it's indexed like a NinjaTrader dataseries do gof.BarData[0] is the last one.
			//iterate the bar fom MinTick to Maxtick
			
			//let's compute the max sell and min sell of last bar
			var bardata=gof.BarData[0];
			int maxbuy=0;
			int maxsell=0;
			
			for (int j=bardata.MinTick; j<=bardata.MaxTick;j++)  // we iterate through all the prices from mintick to maxtick ( real price is xTickSize)
			{
				maxsell= Math.Max(maxsell,bardata.Sells[j]);  // compute maxsells			
				maxbuy=Math.Max(maxbuy,bardata.Buys[j]);	// compute maxbuys
			}
			
			//update max buys plot at the i offset ( i is 1 or 0)
			MaxBuys[0]=maxbuy;
			//update max sells plot  at the i offset ( i is 1 or 0)
			MaxSells[0]=maxsell;	
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries MaxBuys
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries MaxSells
        {
            get { return Values[1]; }
        }

        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private GomTestBuySells[] cacheGomTestBuySells = null;

        private static GomTestBuySells checkGomTestBuySells = new GomTestBuySells();

        /// <summary>
        /// This indicator shows how to access Orderflow data
        /// </summary>
        /// <returns></returns>
        public GomTestBuySells GomTestBuySells()
        {
            return GomTestBuySells(Input);
        }

        /// <summary>
        /// This indicator shows how to access Orderflow data
        /// </summary>
        /// <returns></returns>
        public GomTestBuySells GomTestBuySells(Data.IDataSeries input)
        {
            if (cacheGomTestBuySells != null)
                for (int idx = 0; idx < cacheGomTestBuySells.Length; idx++)
                    if (cacheGomTestBuySells[idx].EqualsInput(input))
                        return cacheGomTestBuySells[idx];

            lock (checkGomTestBuySells)
            {
                if (cacheGomTestBuySells != null)
                    for (int idx = 0; idx < cacheGomTestBuySells.Length; idx++)
                        if (cacheGomTestBuySells[idx].EqualsInput(input))
                            return cacheGomTestBuySells[idx];

                GomTestBuySells indicator = new GomTestBuySells();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                GomTestBuySells[] tmp = new GomTestBuySells[cacheGomTestBuySells == null ? 1 : cacheGomTestBuySells.Length + 1];
                if (cacheGomTestBuySells != null)
                    cacheGomTestBuySells.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheGomTestBuySells = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// This indicator shows how to access Orderflow data
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.GomTestBuySells GomTestBuySells()
        {
            return _indicator.GomTestBuySells(Input);
        }

        /// <summary>
        /// This indicator shows how to access Orderflow data
        /// </summary>
        /// <returns></returns>
        public Indicator.GomTestBuySells GomTestBuySells(Data.IDataSeries input)
        {
            return _indicator.GomTestBuySells(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// This indicator shows how to access Orderflow data
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.GomTestBuySells GomTestBuySells()
        {
            return _indicator.GomTestBuySells(Input);
        }

        /// <summary>
        /// This indicator shows how to access Orderflow data
        /// </summary>
        /// <returns></returns>
        public Indicator.GomTestBuySells GomTestBuySells(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.GomTestBuySells(input);
        }
    }
}
#endregion
